==> tfdataset-1.4.20.tar.gz: tfdataset-1.4.20/tfdataset/csv_to_tfrecords.py <==
"""
Usage:

# Create train data:
python generate_tfrecord.py --label=<LABEL> --csv_input=<PATH_TO_ANNOTATIONS_FOLDER>/train_labels.csv  --output_path=<PATH_TO_ANNOTATIONS_FOLDER>/train.record

# Create test data:
python generate_tfrecord.py --label=<LABEL> --csv_input=<PATH_TO_ANNOTATIONS_FOLDER>/test_labels.csv  --output_path=<PATH_TO_ANNOTATIONS_FOLDER>/test.record
"""

from __future__ import division
from __future__ import print_function
from __future__ import absolute_import

import os
import io
import json
import pandas as pd
import tensorflow as tf
from .dataset_utils import *

from PIL import Image
from pathlib import Path
from collections import namedtuple, OrderedDict


# TO-DO replace this with label map
# for multiple labels add more else if statements


def class_text_to_int(label_list, row_label):
    return label_list[row_label]


def split(df, group):
    data = namedtuple('data', ['filename', 'object'])
    gb = df.groupby(group)
    return [data(filename, gb.get_group(x)) for filename, x in zip(gb.groups.keys(), gb.groups)]


def create_tf_example(label_list, group, path):
    with tf.gfile.GFile(os.path.join(path, '{}'.format(group.filename)), 'rb') as fid:
        encoded_jpg = fid.read()
    encoded_jpg_io = io.BytesIO(encoded_jpg)

    image = Image.open(encoded_jpg_io)
    width, height = image.size

    filename = group.filename.encode('utf8')
    image_format = b'jpg'
    # check if the image format is matching with your images.
    xmins = []
    xmaxs = []
    ymins = []
    ymaxs = []
    classes_text = []
    classes = []

    for index, row in group.object.iterrows():
        xmins.append(row['xmin'] / width)
        xmaxs.append(row['xmax'] / width)
        ymins.append(row['ymin'] / height)
        ymaxs.append(row['ymax'] / height)
        classes_text.append(row['class'].encode('utf8'))
        classes.append(class_text_to_int(label_list, row['class']))

    tf_example = tf.train.Example(features=tf.train.Features(feature={
        'image/height': int64_feature(height),
        'image/width': int64_feature(width),
        'image/filename': bytes_feature(filename),
        'image/source_id': bytes_feature(filename),
        'image/encoded': bytes_feature(encoded_jpg),
        'image/format': bytes_feature(image_format),
        'image/object/bbox/xmin': float_list_feature(xmins),
        'image/object/bbox/xmax': float_list_feature(xmaxs),
        'image/object/bbox/ymin': float_list_feature(ymins),
        'image/object/bbox/ymax': float_list_feature(ymaxs),
        'image/object/class/text': bytes_list_feature(classes_text),
        'image/object/class/label': int64_list_feature(classes),
    }))
    return tf_example


def main(args):
    # read label list
    object_name = args.object
    path_to_object_label_list = '{}.json'.format(object_name)
    f = open(Path(__file__).parent / Path(path_to_object_label_list), "rb")
    label_list = json.load(f)

    # write tfrecords
    writer = tf.python_io.TFRecordWriter(
        args.csv_path + '/{}.record'.format(args.data_type))
    path = os.path.join(os.getcwd(), args.image_dir)
    examples = pd.read_csv(
        args.csv_path + 'tfdataset/{}.csv'.format(args.data_type))
    grouped = split(examples, 'filename')
    for group in grouped:
        try:
            tf_example = create_tf_example(label_list, group, path)
            writer.write(tf_example.SerializeToString())
        except:
            continue

    writer.close()
    output_path = os.getcwd() + '/{}.record'.format(args.data_type)
    print('Successfully created the TFRecords: {}'.format(output_path))


if __name__ == '__main__':
    tf.app.run()

==> tfdataset-1.4.25.tar.gz: tfdataset-1.4.25/tfdataset/csv_to_tfrecords.py <==
"""
Usage:

# Create train data:
python generate_tfrecord.py --label=<LABEL> --csv_input=<PATH_TO_ANNOTATIONS_FOLDER>/train_labels.csv  --output_path=<PATH_TO_ANNOTATIONS_FOLDER>/train.record

# Create test data:
python generate_tfrecord.py --label=<LABEL> --csv_input=<PATH_TO_ANNOTATIONS_FOLDER>/test_labels.csv  --output_path=<PATH_TO_ANNOTATIONS_FOLDER>/test.record
"""

from __future__ import division
from __future__ import print_function
from __future__ import absolute_import

import os
import io
import json
import pandas as pd
import tensorflow as tf
from .dataset_utils import *

from PIL import Image
from pathlib import Path
from collections import namedtuple, OrderedDict


# TO-DO replace this with label map
# for multiple labels add more else if statements


def class_text_to_int(label_list, row_label):
    return label_list[row_label]


def split(df, group):
    data = namedtuple('data', ['filename', 'object'])
    gb = df.groupby(group)
    return [data(filename, gb.get_group(x)) for filename, x in zip(gb.groups.keys(), gb.groups)]


def create_tf_example(label_list, group, path):
    with tf.gfile.GFile(os.path.join(path, '{}'.format(group.filename)), 'rb') as fid:
        encoded_jpg = fid.read()
    encoded_jpg_io = io.BytesIO(encoded_jpg)

    image = Image.open(encoded_jpg_io)
    width, height = image.size

    filename = group.filename.encode('utf8')
    image_format = b'jpg'
    # check if the image format is matching with your images.
    xmins = []
    xmaxs = []
    ymins = []
    ymaxs = []
    classes_text = []
    classes = []

    for index, row in group.object.iterrows():
        xmins.append(row['xmin'] / width)
        xmaxs.append(row['xmax'] / width)
        ymins.append(row['ymin'] / height)
        ymaxs.append(row['ymax'] / height)
        classes_text.append(row['class'].encode('utf8'))
        classes.append(class_text_to_int(label_list, row['class']))

    tf_example = tf.train.Example(features=tf.train.Features(feature={
        'image/height': int64_feature(height),
        'image/width': int64_feature(width),
        'image/filename': bytes_feature(filename),
        'image/source_id': bytes_feature(filename),
        'image/encoded': bytes_feature(encoded_jpg),
        'image/format': bytes_feature(image_format),
        'image/object/bbox/xmin': float_list_feature(xmins),
        'image/object/bbox/xmax': float_list_feature(xmaxs),
        'image/object/bbox/ymin': float_list_feature(ymins),
        'image/object/bbox/ymax': float_list_feature(ymaxs),
        'image/object/class/text': bytes_list_feature(classes_text),
        'image/object/class/label': int64_list_feature(classes),
    }))
    return tf_example


def main(args):
    # read label list
    object_name = args.object
    path_to_object_label_list = '{}.json'.format(object_name)
    f = open(Path(__file__).parent / Path(path_to_object_label_list), "rb")
    label_list = json.load(f)

    # write tfrecords
    writer = tf.python_io.TFRecordWriter(
        args.csv_path + '/{}.record'.format(args.data_type))
    path = os.path.join(os.getcwd(), args.image_dir)
    examples = pd.read_csv(
        args.csv_path + '/{}.csv'.format(args.data_type))
    grouped = split(examples, 'filename')
    for group in grouped:
        try:
            tf_example = create_tf_example(label_list, group, path)
            writer.write(tf_example.SerializeToString())
        except:
            continue

    writer.close()
    output_path = os.getcwd() + '/{}.record'.format(args.data_type)
    print('Successfully created the TFRecords: {}'.format(output_path))


if __name__ == '__main__':
    tf.app.run()
